@@ -1,9 +1,9 @@
 package App::PDFUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-02-03'; # DATE
+our $DATE = '2021-01-30'; # DATE
 our $DIST = 'App-PDFUtils'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -180,7 +180,7 @@ sub remove_pdf_password {
         for my $p (@{ $args{passwords} }) {
             my ($stdout, $stderr);
             IPC::System::Options::system(
-                {log => 1, capture_stdout => \$stdout, capture_stderr => \$stderr},
+                {log => 1, fail_log_level => 'info', capture_stdout => \$stdout, capture_stderr => \$stderr},
                 "qpdf", "--password=$p", "--decrypt", $f, $tempf);
             my $err = $?;# ? Proc::ChildError::explain_child_error() : '';
             if ($err && $stderr =~ /: invalid password$/) {
@@ -233,7 +233,7 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.003 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2020-02-03.
+This document describes version 0.004 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2021-01-30.
 
 =head1 SYNOPSIS
 
@@ -360,26 +360,19 @@ Source repository is at L<https://github.com/perlancar/perl-App-PDFUtils>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PDFUtils>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-PDFUtils/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-
-L<remove-pdf-password>.
-
-L<add-pdf-password>.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
